@@ -21,6 +21,7 @@ package org.apache.maven.enforcer.rule.api;
 
 import java.util.List;
 import java.util.Map;
+import java.util.function.Supplier;
 
 import javax.annotation.Nonnull;
 
@@ -59,7 +60,7 @@ public interface EnforcerRuleHelper
      * @throws ComponentLookupException the component lookup exception
      */
     @Nonnull
-    Object getComponent ( Class clazz )
+    <T> T getComponent ( Class<T> clazz )
         throws ComponentLookupException;
 
     /**
@@ -88,6 +89,19 @@ public interface EnforcerRuleHelper
     Object getComponent ( String role, String roleHint )
         throws ComponentLookupException;
 
+    /**
+     * Gets the component.
+     *
+     * @param clazz the clazz
+     * @param roleHint the role hint
+     *
+     * @return the component
+     *
+     * @throws ComponentLookupException the component lookup exception
+     */
+    <T> T getComponent ( Class<T> clazz, String roleHint )
+        throws ComponentLookupException;
+    
     /**
      * Gets the component map.
      *
@@ -97,7 +111,7 @@ public interface EnforcerRuleHelper
      *
      * @throws ComponentLookupException the component lookup exception
      */
-    Map getComponentMap ( String role )
+    Map<String, ?> getComponentMap ( String role )
         throws ComponentLookupException;
 
     /**
@@ -109,7 +123,7 @@ public interface EnforcerRuleHelper
      *
      * @throws ComponentLookupException the component lookup exception
      */
-    List getComponentList ( String role )
+    List<?> getComponentList ( String role )
         throws ComponentLookupException;
 
     /**
@@ -118,4 +132,13 @@ public interface EnforcerRuleHelper
      * @return the container
      */
     PlexusContainer getContainer();
+
+    /**
+     * Gets a cached value, or uses the provided producer to compute it.
+     *
+     * @param key a key to identify the value stored
+     * @param producer a supplier for the value if it's not already present
+     * @return a previously-cached or freshly-computed value
+     */
+    Object getCache( String key, Supplier<?> producer );
 }
