@@ -59,11 +59,7 @@ public abstract class AbstractRequireFiles
      */
     abstract String getErrorMsg();
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.maven.enforcer.rule.api.EnforcerRule#execute(org.apache.maven.enforcer.rule.api.EnforcerRuleHelper)
-     */
+    @Override
     public void execute( EnforcerRuleHelper helper )
         throws EnforcerRuleException
     {
@@ -73,7 +69,7 @@ public abstract class AbstractRequireFiles
             throw new EnforcerRuleException( "The file list is empty and Null files are disabled." );
         }
 
-        List<File> failures = new ArrayList<File>();
+        List<File> failures = new ArrayList<>();
         for ( File file : files )
         {
             if ( !allowNulls && file == null )
@@ -94,7 +90,7 @@ public abstract class AbstractRequireFiles
             StringBuilder buf = new StringBuilder();
             if ( message != null )
             {
-                buf.append( message + "\n" );
+                buf.append( message + System.lineSeparator() );
             }
             buf.append( getErrorMsg() );
 
@@ -102,11 +98,11 @@ public abstract class AbstractRequireFiles
             {
                 if ( file != null )
                 {
-                    buf.append( file.getAbsolutePath() + "\n" );
+                    buf.append( file.getAbsolutePath() + System.lineSeparator() );
                 }
                 else
                 {
-                    buf.append( "(an empty filename was given and allowNulls is false)\n" );
+                    buf.append( "(an empty filename was given and allowNulls is false)" + System.lineSeparator() );
                 }
             }
 
@@ -114,14 +110,7 @@ public abstract class AbstractRequireFiles
         }
     }
 
-    /**
-     * If your rule is cacheable, you must return a unique id when parameters or conditions change that would cause the
-     * result to be different. Multiple cached results are stored based on their id. The easiest way to do this is to
-     * return a hash computed from the values of your parameters. If your rule is not cacheable, then the result here is
-     * not important, you may return anything.
-     *
-     * @return the cache id
-     */
+    @Override
     public String getCacheId()
     {
         return Integer.toString( hashCode( files ) );
@@ -140,36 +129,21 @@ public abstract class AbstractRequireFiles
         if ( items != null )
         {
             hash = 1;
-            for ( int i = 0; i < items.length; i++ )
+            for ( Object item : items )
             {
-                Object item = items[i];
                 hash = 31 * hash + ( item == null ? 0 : item.hashCode() );
             }
         }
         return hash;
     }
 
-    /**
-     * This tells the system if the results are cacheable at all. Keep in mind that during forked builds and other
-     * things, a given rule may be executed more than once for the same project. This means that even things that change
-     * from project to project may still be cacheable in certain instances.
-     *
-     * @return <code>true</code> if rule is cacheable
-     */
+    @Override
     public boolean isCacheable()
     {
         return true;
     }
 
-    /**
-     * If the rule is cacheable and the same id is found in the cache, the stored results are passed to this method to
-     * allow double checking of the results. Most of the time this can be done by generating unique ids, but sometimes
-     * the results of objects returned by the helper need to be queried. You may for example, store certain objects in
-     * your rule and then query them later.
-     *
-     * @param cachedRule the cached rule
-     * @return <code>true</code> if the stored results are valid for the same id.
-     */
+    @Override
     public boolean isResultValid( EnforcerRule cachedRule )
     {
         return true;
