@@ -24,23 +24,22 @@ import java.util.Collections;
 import java.util.List;
 
 import org.apache.maven.artifact.Artifact;
-import org.apache.maven.artifact.factory.ArtifactFactory;
-import org.apache.maven.artifact.metadata.ArtifactMetadataSource;
 import org.apache.maven.artifact.repository.ArtifactRepository;
-import org.apache.maven.artifact.resolver.ArtifactCollector;
 import org.apache.maven.artifact.resolver.filter.ArtifactFilter;
 import org.apache.maven.enforcer.rule.api.EnforcerRule;
 import org.apache.maven.enforcer.rule.api.EnforcerRuleException;
 import org.apache.maven.enforcer.rule.api.EnforcerRuleHelper;
+import org.apache.maven.execution.MavenSession;
 import org.apache.maven.plugin.logging.Log;
 import org.apache.maven.plugins.enforcer.utils.DependencyVersionMap;
+import org.apache.maven.project.DefaultProjectBuildingRequest;
 import org.apache.maven.project.MavenProject;
-import org.apache.maven.shared.dependency.tree.DependencyNode;
-import org.apache.maven.shared.dependency.tree.DependencyTreeBuilder;
-import org.apache.maven.shared.dependency.tree.DependencyTreeBuilderException;
+import org.apache.maven.project.ProjectBuildingRequest;
+import org.apache.maven.shared.dependency.graph.DependencyCollectorBuilder;
+import org.apache.maven.shared.dependency.graph.DependencyCollectorBuilderException;
+import org.apache.maven.shared.dependency.graph.DependencyNode;
 import org.codehaus.plexus.component.configurator.expression.ExpressionEvaluationException;
 import org.codehaus.plexus.component.repository.exception.ComponentLookupException;
-import org.codehaus.plexus.i18n.I18N;
 
 /**
  * @author <a href="mailto:rex@e-hoffman.org">Rex Hoffman</a>
@@ -48,11 +47,8 @@ import org.codehaus.plexus.i18n.I18N;
 public class DependencyConvergence
     implements EnforcerRule
 {
-
     private static Log log;
 
-    private static I18N i18n;
-
     private boolean uniqueVersions;
 
     public void setUniqueVersions( boolean uniqueVersions )
@@ -78,32 +74,32 @@ public class DependencyConvergence
         try
         {
             MavenProject project = (MavenProject) helper.evaluate( "${project}" );
-            DependencyTreeBuilder dependencyTreeBuilder =
-                (DependencyTreeBuilder) helper.getComponent( DependencyTreeBuilder.class );
+            MavenSession session = (MavenSession) helper.evaluate( "${session}" );
+            DependencyCollectorBuilder dependencyCollectorBuilder =
+                helper.getComponent( DependencyCollectorBuilder.class );
             ArtifactRepository repository = (ArtifactRepository) helper.evaluate( "${localRepository}" );
-            ArtifactFactory factory = (ArtifactFactory) helper.getComponent( ArtifactFactory.class );
-            ArtifactMetadataSource metadataSource =
-                (ArtifactMetadataSource) helper.getComponent( ArtifactMetadataSource.class );
-            ArtifactCollector collector = (ArtifactCollector) helper.getComponent( ArtifactCollector.class );
-            ArtifactFilter filter = null; // we need to evaluate all scopes
-            DependencyNode node = dependencyTreeBuilder.buildDependencyTree( project, repository, factory,
-                                                                             metadataSource, filter, collector );
-            return node;
+
+            ProjectBuildingRequest buildingRequest =
+                new DefaultProjectBuildingRequest( session.getProjectBuildingRequest() );
+            buildingRequest.setProject( project );
+            buildingRequest.setLocalRepository( repository );
+            ArtifactFilter filter = ( Artifact a ) -> ( "compile".equalsIgnoreCase( a.getScope () )
+                    || "runtime".equalsIgnoreCase( a.getScope () ) )
+                    && !a.isOptional();
+
+            return dependencyCollectorBuilder.collectDependencyGraph( buildingRequest, filter );
         }
-        catch ( ExpressionEvaluationException e )
-        {
-            throw new EnforcerRuleException( "Unable to lookup an expression " + e.getLocalizedMessage(), e );
-        }
-        catch ( ComponentLookupException e )
+        catch ( ExpressionEvaluationException | ComponentLookupException e )
         {
             throw new EnforcerRuleException( "Unable to lookup a component " + e.getLocalizedMessage(), e );
         }
-        catch ( DependencyTreeBuilderException e )
+        catch ( DependencyCollectorBuilderException e )
         {
             throw new EnforcerRuleException( "Could not build dependency tree " + e.getLocalizedMessage(), e );
         }
     }
 
+    @Override
     public void execute( EnforcerRuleHelper helper )
         throws EnforcerRuleException
     {
@@ -113,15 +109,11 @@ public class DependencyConvergence
         }
         try
         {
-            if ( i18n == null )
-            {
-                i18n = (I18N) helper.getComponent( I18N.class );
-            }
             DependencyNode node = getNode( helper );
             DependencyVersionMap visitor = new DependencyVersionMap( log );
             visitor.setUniqueVersions( uniqueVersions );
             node.accept( visitor );
-            List<CharSequence> errorMsgs = new ArrayList<CharSequence>();
+            List<CharSequence> errorMsgs = new ArrayList<>();
             errorMsgs.addAll( getConvergenceErrorMsgs( visitor.getConflictedVersionNumbers() ) );
             for ( CharSequence errorMsg : errorMsgs )
             {
@@ -133,28 +125,19 @@ public class DependencyConvergence
                     + "See above detailed error message." );
             }
         }
-        catch ( ComponentLookupException e )
-        {
-            throw new EnforcerRuleException( "Unable to lookup a component " + e.getLocalizedMessage(), e );
-        }
         catch ( Exception e )
         {
             throw new EnforcerRuleException( e.getLocalizedMessage(), e );
         }
     }
 
-    private String getFullArtifactName( Artifact artifact )
-    {
-        return artifact.getGroupId() + ":" + artifact.getArtifactId() + ":" + artifact.getVersion();
-    }
-
     private StringBuilder buildTreeString( DependencyNode node )
     {
-        List<String> loc = new ArrayList<String>();
+        List<String> loc = new ArrayList<>();
         DependencyNode currentNode = node;
         while ( currentNode != null )
         {
-            loc.add( getFullArtifactName( currentNode.getArtifact() ) );
+            loc.add( currentNode.getArtifact().toString() );
             currentNode = currentNode.getParent();
         }
         Collections.reverse( loc );
@@ -166,14 +149,14 @@ public class DependencyConvergence
                 builder.append( "  " );
             }
             builder.append( "+-" + loc.get( i ) );
-            builder.append( "\n" );
+            builder.append( System.lineSeparator() );
         }
         return builder;
     }
 
     private List<String> getConvergenceErrorMsgs( List<List<DependencyNode>> errors )
     {
-        List<String> errorMsgs = new ArrayList<String>();
+        List<String> errorMsgs = new ArrayList<>();
         for ( List<DependencyNode> nodeList : errors )
         {
             errorMsgs.add( buildConvergenceErrorMsg( nodeList ) );
@@ -184,49 +167,34 @@ public class DependencyConvergence
     private String buildConvergenceErrorMsg( List<DependencyNode> nodeList )
     {
         StringBuilder builder = new StringBuilder();
-        builder.append( "\nDependency convergence error for " + getFullArtifactName( nodeList.get( 0 ).getArtifact() )
-            + " paths to dependency are:\n" );
+        builder.append( System.lineSeparator() + "Dependency convergence error for "
+            + nodeList.get( 0 ).getArtifact().toString()
+            + " paths to dependency are:" + System.lineSeparator() );
         if ( nodeList.size() > 0 )
         {
             builder.append( buildTreeString( nodeList.get( 0 ) ) );
         }
         for ( DependencyNode node : nodeList.subList( 1, nodeList.size() ) )
         {
-            builder.append( "and\n" );
+            builder.append( "and" + System.lineSeparator() );
             builder.append( buildTreeString( node ) );
         }
         return builder.toString();
     }
 
-    /**
-     * If your rule is cacheable, you must return a unique id when parameters or conditions change that would cause the
-     * result to be different. Multiple cached results are stored based on their id. The easiest way to do this is to
-     * return a hash computed from the values of your parameters. If your rule is not cacheable, then the result here is
-     * not important, you may return anything.
-     */
+    @Override
     public String getCacheId()
     {
         return "";
     }
 
-    /**
-     * This tells the system if the results are cacheable at all. Keep in mind that during forked builds and other
-     * things, a given rule may be executed more than once for the same project. This means that even things that change
-     * from project to project may still be cacheable in certain instances.
-     */
+    @Override
     public boolean isCacheable()
     {
         return false;
     }
 
-    /**
-     * If the rule is cacheable and the same id is found in the cache, the stored results are passed to this method to
-     * allow double checking of the results. Most of the time this can be done by generating unique ids, but sometimes
-     * the results of objects returned by the helper need to be queried. You may for example, store certain objects in
-     * your rule and then query them later.
-     * 
-     * @param rule
-     */
+    @Override
     public boolean isResultValid( EnforcerRule rule )
     {
         return false;
