@@ -19,31 +19,22 @@ package org.apache.maven.plugins.enforcer;
  * under the License.
  */
 
-import junit.framework.TestCase;
-
 import org.apache.maven.enforcer.rule.api.EnforcerRuleException;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test AlwaysPass rule.
+ * 
  * @author Ben Lidgey
  * @see AlwaysPass
  */
-public class TestAlwaysPass extends TestCase
+public class TestAlwaysPass
 {
-
+    @Test
     public void testExecute()
+        throws EnforcerRuleException
     {
-        final AlwaysPass rule = new AlwaysPass();
-        try
-        {
-            // execute rule -- should NOT throw EnforcerRuleException
-            rule.execute( EnforcerTestUtils.getHelper() );
-            assertTrue( true );
-        }
-        catch ( EnforcerRuleException e )
-        {
-            fail( "Should NOT throw EnforcerRuleException" );
-        }
+        AlwaysPass rule = new AlwaysPass();
+        rule.execute( EnforcerTestUtils.getHelper() );
     }
-
 }
